Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1405)

Unified Diff: remoting/host/client_session.h

Issue 12220092: Rename ClientDimensions to ClientResolution and add pixel-size and DPI fields. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix typos in ChromotingInstance. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/client_session.h
diff --git a/remoting/host/client_session.h b/remoting/host/client_session.h
index 6d32adfeca64ad8055824692a2a804c17a0d47f7..5ed34f30ad0099df70cc151110ca97a8d8548592 100644
--- a/remoting/host/client_session.h
+++ b/remoting/host/client_session.h
@@ -78,10 +78,11 @@ class ClientSession
const std::string& channel_name,
const protocol::TransportRoute& route) = 0;
- // Called when the initial client dimensions are received, and when they
- // change.
- virtual void OnClientDimensionsChanged(ClientSession* client,
- const SkISize& size) = 0;
+ // Called when the initial client resolution is received, and when it
+ // changes.
+ virtual void OnClientResolutionChanged(ClientSession* client,
+ const SkISize& size,
+ const SkIPoint& dpi) = 0;
protected:
virtual ~EventHandler() {}
@@ -102,8 +103,8 @@ class ClientSession
const base::TimeDelta& max_duration);
// protocol::HostStub interface.
- virtual void NotifyClientDimensions(
- const protocol::ClientDimensions& dimensions) OVERRIDE;
+ virtual void NotifyClientResolution(
+ const protocol::ClientResolution& resolution) OVERRIDE;
virtual void ControlVideo(
const protocol::VideoControl& video_control) OVERRIDE;
virtual void ControlAudio(

Powered by Google App Engine
This is Rietveld 408576698